@@ -1,5 +1,6 @@
 from django.conf import settings
 
+from authlib.integrations.httpx_client import AsyncOAuth2Client
 from authlib.integrations.requests_client import OAuth2Session
 
 from django_serverless_oauth_session.models import OAuthToken
@@ -55,15 +56,22 @@ def create_new(token: dict):
     pynamo_token.save()
 
 
-def get_tokenless_oauth_session():
+def get_tokenless_oauth_session(use_httpx=False):
     """
     Used for obtaining a token
     """
-    client = OAuth2Session(
-        settings.OAUTH_CLIENT_ID,
-        settings.OAUTH_CLIENT_SECRET,
-        scope=settings.OAUTH_SCOPE,
-    )
+    if use_httpx:
+        client = AsyncOAuth2Client(
+            settings.OAUTH_CLIENT_ID,
+            settings.OAUTH_CLIENT_SECRET,
+            scope=settings.OAUTH_SCOPE,
+        )
+    else:
+        client = OAuth2Session(
+            settings.OAUTH_CLIENT_ID,
+            settings.OAUTH_CLIENT_SECRET,
+            scope=settings.OAUTH_SCOPE,
+        )
     return client
 
 
